const app = getApp()

import Notify from '@vant/weapp/notify/notify';

import {
    getMeetingRoomServiceAndEquipmentRq,
    queryServiceMsgRq
} from "../../../../api/meeting/meetingRoom.js"


import {
    selfFormatTimeYMD,
} from "../../../../utils/util.js"

Page({

    /**
     * 页面的初始数据
     */
    data: {
        IMG_NAME: app.IMG_NAME,
        meetingRoomId: null,
        detail: {},
        msg: '',
        serviceList: [],
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad(options) {
        let _this = this;
        let serviceList = JSON.parse(options.serviceList)
        _this.setData({
            ...options,
            serviceList
        })
        // 获取数据
        _this.getData();
    },

    // 获取数据
    getData() {
        let _this = this;
        if (!(_this.data.serviceList && _this.data.serviceList.length > 0)) {
            // 查询服务列表
            getMeetingRoomServiceAndEquipmentRq(_this.data.meetingRoomId).then(res => {
                let incrementServiceList = res.data.roomFServe.map(item => {
                    return {
                        serveId: item.id,
                        serveName: item.serveName,
                        isSelect: false,
                        num: '',
                        type: 'increment'
                    }
                })
                let freeServiceList = res.data.roomFreeServe.map(item => {
                    return {
                        serveId: item.id,
                        serveName: item.serveName,
                        isSelect: false,
                        num: '',
                        type: 'free'
                    }
                })
                let serviceList = incrementServiceList.concat(freeServiceList)
                _this.setData({
                    serviceList
                })
            })
        }

        // 查询服务信息
        queryServiceMsgRq({
            "dictType": "server_info"
        }).then(res => {
            console.log('queryServiceMsgRq', res);
            for (let i = 0; i < res.data.length; i++) {
                if (res.data[i].dictValue == app.tenantId) {
                    _this.setData({
                        msg: res.data[i].dictLabel
                    })
                    break;
                }
            }
        })
    },


    // 服务选择
    checkBoxClick(e) {
        let _this = this;
        console.log('checkBoxClick', e);
        // get param
        let id = e.target.dataset.id
        let serviceList = _this.data.serviceList.map(item => {
            if (item.serveId == id) {
                item.isSelect = !item.isSelect
            }
            return item
        })
        _this.setData({
            serviceList
        })
    },

    // 服务输入数量
    inputChange(e) {
        let _this = this;
        console.log('inputChange', e);
        // get param
        let id = e.currentTarget.dataset.id
        let num = e.detail;
        let serviceList = _this.data.serviceList.map(item => {
            if (item.serveId == id) {
                item.num = num
            }
            return item
        })
        _this.setData({
            serviceList
        })
    },

    // 确定
    submit() {
        let _this = this;
        let serviceList = _this.data.serviceList
        let startTime = _this.data.startTime
        // 如果选择增值服务需要提前2天
        if (serviceList.find(item => item.type == 'increment' && item.isSelect)) {
            let startTimeMS = new Date(selfFormatTimeYMD(startTime) + ' 00:00:00').getTime()
            let nowTimeMS = new Date(selfFormatTimeYMD(new Date()) + ' 00:00:00').getTime()
            nowTimeMS = nowTimeMS + (1000 * 60 * 60 * 24 * 2)
            if (startTimeMS < nowTimeMS) {
                // 错误提示
                Notify({
                    type: 'danger',
                    message: `A类会议服务需提前两天预约`
                });
                return
            }
        }
        let pages = getCurrentPages(); //获取page
        let prevPage = pages[pages.length - 2]; //上一个页面（父页面）
        prevPage.setData({
            serviceList: _this.data.serviceList
        })
        wx.navigateBack();
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady() {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow() {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide() {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload() {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh() {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom() {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage() {

    }
})